# Adding decoders

Adding your device protocol to Theengs enable to increase interoperability and to create new use cases with your device. You will find below some guidance to do that. 

You can do a pull request directly to the [Decoder Repository](https://github.com/theengs/decoder) by leveraging the Theengs Decoder [example](https://theengs.github.io/decoder/participate/adding-decoders.html).
